@@ -4,7 +4,7 @@
 #    you may not use this file except in compliance with the License.
 #    You may obtain a copy of the License at
 #
-#       http://www.apache.org/licenses/LICENSE-2.0
+#       https://www.apache.org/licenses/LICENSE-2.0
 #
 #    Unless required by applicable law or agreed to in writing, software
 #    distributed under the License is distributed on an "AS IS" BASIS,
@@ -12,9 +12,11 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-#' Predict fitdist
+#' Predict 
 #'
 #' @inheritParams params
+#' @seealso [stats::predict()]
+#' @family predict
 #' @export
 #' @examples
 #' predict(boron_lnorm, percent = c(5L, 50L))
@@ -22,22 +24,18 @@ predict.fitdist <- function(object, percent = 1:99, ci = FALSE, level = 0.95,
                             nboot = 1000, parallel = NULL, ncpus = 1,
                             ...) {
   chk_unused(...)
-  if (missing(ci)) {
-    deprecate_soft("0.1.0", "ssdtools::predict(ci = )",
-      details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.",
-      id = "predict"
-    )
+  if(missing(ci)) {
+    deprecate_soft("0.1.0", "ssdtools::predict(ci = )", details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.", 
+                   id = "predict")
   }
-
+  
   ssd_hc(object,
-    percent = percent, ci = ci, level = level,
-    nboot = nboot, parallel = parallel, ncpus = ncpus
+         percent = percent, ci = ci, level = level,
+         nboot = nboot, parallel = parallel, ncpus = ncpus
   )
 }
 
-#' Predict censored fitdist
-#'
-#' @inheritParams params
+#' @rdname predict.fitdist
 #' @export
 #' @examples
 #' predict(fluazinam_lnorm, percent = c(5L, 50L))
@@ -45,21 +43,17 @@ predict.fitdistcens <- function(object, percent = 1:99, ci = FALSE, level = 0.95
                                 nboot = 1000, parallel = NULL, ncpus = 1,
                                 ...) {
   chk_unused(...)
-  if (missing(ci)) {
-    deprecate_soft("0.1.0", "ssdtools::predict(ci = )",
-      details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.",
-      id = "predict"
-    )
+  if(missing(ci)) {
+    deprecate_soft("0.1.0", "ssdtools::predict(ci = )", details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.", 
+                   id = "predict")
   }
   ssd_hc(object,
-    percent = percent, ci = ci, level = level,
-    nboot = nboot, parallel = parallel, ncpus = ncpus
+         percent = percent, ci = ci, level = level,
+         nboot = nboot, parallel = parallel, ncpus = ncpus
   )
 }
 
-#' Predict fitdists
-#'
-#' @inheritParams params
+#' @rdname predict.fitdist 
 #' @export
 #' @examples
 #' predict(boron_dists)
@@ -68,22 +62,18 @@ predict.fitdists <- function(object, percent = 1:99, ci = FALSE,
                              average = TRUE, ic = "aicc",
                              ...) {
   chk_unused(...)
-  if (missing(ci)) {
-    deprecate_soft("0.1.0", "ssdtools::predict(ci = )",
-      details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.",
-      id = "predict"
-    )
+  if(missing(ci)) {
+    deprecate_soft("0.1.0", "ssdtools::predict(ci = )", details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.", 
+                   id = "predict")
   }
   ssd_hc(object,
-    percent = percent, ci = ci, level = level,
-    nboot = nboot, parallel = parallel, ncpus = ncpus,
-    average = average, ic = ic
+         percent = percent, ci = ci, level = level,
+         nboot = nboot, parallel = parallel, ncpus = ncpus,
+         average = average, ic = ic
   )
 }
 
-#' Predict censored fitdists
-#'
-#' @inheritParams params
+#' @rdname predict.fitdist 
 #' @export
 #' @examples
 #' predict(fluazinam_dists)
@@ -91,15 +81,13 @@ predict.fitdistscens <- function(object, percent = 1:99, ci = FALSE,
                                  level = 0.95, nboot = 1000, parallel = NULL, ncpus = 1,
                                  average = TRUE, ic = "aic", ...) {
   chk_unused(...)
-  if (missing(ci)) {
-    deprecate_soft("0.1.0", "ssdtools::predict(ci = )",
-      details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.",
-      id = "predict"
-    )
+  if(missing(ci)) {
+    deprecate_soft("0.1.0", "ssdtools::predict(ci = )", details = "In particular, the `ci` has been switched from TRUE to FALSE. To retain the previous behaviour of calculating confidence intervals set `ci = TRUE`.", 
+                   id = "predict")
   }
   ssd_hc(object,
-    percent = percent, ci = ci, level = level,
-    nboot = nboot, parallel = parallel, ncpus = ncpus,
-    average = average, ic = ic
+         percent = percent, ci = ci, level = level,
+         nboot = nboot, parallel = parallel, ncpus = ncpus,
+         average = average, ic = ic
   )
 }
