@@ -10,13 +10,14 @@ test_that("deprecated llog", {
   )
   set.seed(101)
   lifecycle::expect_deprecated(pred <- predict(dist, percent = 1, ci = TRUE, nboot = 10L))
-  expect_equal(as.data.frame(pred), structure(list(
-    percent = 1, est = 0.460388430679064, se = 0.305015200817155,
-    lcl = 0.124204402582017, ucl = 1.04527103315379, dist = "llog"
-  ), row.names = c(
-    NA,
-    -1L
-  ), class = "data.frame"))
+  expect_is(pred, "tbl_df")
+  expect_identical(colnames(pred), c("percent", "est", "se", "lcl", "ucl", "dist"))
+  expect_identical(pred$percent, 1)
+  expect_equal(pred$est, 0.460388430679064)
+  expect_equal(pred$se, 0.305015200817155)
+  expect_equal(pred$lcl, 0.124204402582017)
+  expect_equal(pred$ucl, 1.04527103315379)
+  expect_equal(pred$dist, "llog")
 })
 
 test_that("error llog", {
